##  Modifying the Established Link
You can modify the link between the discovered item and the linked fact sheet if it was linked inadvertently or if a better alternative exists.
To modify the link, do the following:
  1. Click on the linked item. This opens the side panel.
  2. Hover over the linked application fact sheet and click Edit.
  3. Search and select the desired fact sheet.
  4. Click Link to finish reestablishing the link.
